The following object contains a list of 2 xpose_data objects generated in the RsNLME example script
TwoCptIVBolus_FitBaseModel_CovariateSearch_VPC_BootStrapping.R.
xpdb_NLMEList of 2 xpose_data objects constructed from NLME model output.
xpdb_NLME$`TwCpt_IVBolus_FOCE-ELS` is an xpose_data object created from the base model in RsNLME example script.
The model can be used as a reference to compare model diagnostics in final model.
xpdb_NLME$`TwCpt_IVBolus_SelectedCovariateModel_FOCE-ELS` is an xpose_data object created from the final model
in the RsNLME example script. The final model includes selected covariate BodyWeight added from the results of
stepwise covariate search.