The following object contains of list of 2 xpose_data objects:
xpdb_NONMEMList of 2 xpose_data objects constructed from NONMEM model output.
xpdb_NONMEM$ex_pk is an xpose_data object from xpose::xpdb_ex_pk. The model contains multiple
covariates and can be used to explore covariate model diagnostics.
xpdb_NONMEM$mult_obs is an xpose_data object created from NONMEM model with multiple observed variables.
Users will see that appropriate model diagnostic plots are automatically facetted by DVID
in the Shiny GUI.